import { CommonModule } from '@angular/common';
import { setTheme } from 'ngx-bootstrap/utils';
import { __awaiter, __decorate, __metadata } from 'tslib';
import { Component, HostBinding, NgModule } from '@angular/core';
import { BaseUIComponent, ContainerProperties, propDescription, CoreService, CoreModule } from '@ngx-dynamic-components/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ContainerComponent extends BaseUIComponent {
    constructor() {
        super(...arguments);
        this.isContainer = true;
        this.isFluidContainer = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.uiModel.itemProperties.fullWidth) {
                this.isFluidContainer = true;
                this.isContainer = false;
            }
        });
    }
}
ContainerComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-container',
                template: `
    <dc-container-row *ngFor="let item of uiModel.children" [ngStyle]="getStyles(item.itemProperties)"
      (changedDataModel)="changedDataModel.emit($event)"
      [uiModel]='item'
      [dataModel]='dataModel'
      [workflowEngine]='workflowEngine'
    ></dc-container-row>
  `,
                styles: [`
    :host {
      display: block;
    }
  `]
            }] }
];
ContainerComponent.propDecorators = {
    isContainer: [{ type: HostBinding, args: ['class.container',] }],
    isFluidContainer: [{ type: HostBinding, args: ['class.container-fluid',] }]
};
class BSContainerProperties extends ContainerProperties {
}
__decorate([
    propDescription({
        description: 'Is full width container, default false',
        example: 'true',
    }),
    __metadata("design:type", Boolean)
], BSContainerProperties.prototype, "fullWidth", void 0);
/** @type {?} */
const example = {
    title: 'Bootstrap container example',
    uiModel: {
        type: 'bootstrap:container',
        containerProperties: {
            width: '100%'
        },
        itemProperties: {
            width: '20%',
            padding: '10px'
        },
        children: [{
                type: 'bootstrap:bs-row',
                containerProperties: {},
                children: [{
                        type: 'material:text',
                        containerProperties: {
                            fxFlex: '1 1 auto'
                        },
                        itemProperties: {
                            text: 'Row 1 / Item 1',
                        }
                    }, {
                        type: 'material:text',
                        containerProperties: {
                            fxFlex: '1 1 auto'
                        },
                        itemProperties: {
                            text: 'Row 1 / Item 2',
                        }
                    }]
            }, {
                type: 'bootstrap:bs-row',
                containerProperties: {},
                children: [{
                        type: 'material:text',
                        containerProperties: {
                            fxFlex: '1 1 auto'
                        },
                        itemProperties: {
                            text: 'Row 2 / Item 1',
                        }
                    }, {
                        type: 'material:text',
                        containerProperties: {
                            fxFlex: '1 1 auto'
                        },
                        itemProperties: {
                            text: 'Row 2 / Item 2',
                        }
                    }]
            }]
    },
    dataModel: {}
};
/** @type {?} */
const containerDescriptor = {
    name: 'container',
    packageName: 'bootstrap',
    category: 'Layout',
    description: 'Bootstrap container',
    itemProperties: BSContainerProperties,
    component: ContainerComponent,
    example
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ContainerRowComponent extends BaseUIComponent {
    constructor() {
        super(...arguments);
        this.isRow = true;
    }
}
ContainerRowComponent.decorators = [
    { type: Component, args: [{
                selector: 'dc-container-row',
                template: `
    <div *ngFor="let item of uiModel.children" class="col-sm p-4">
      <dc-ui-selector
          (changedDataModel)="changedDataModel.emit($event)"
          [uiModel]='item'
          [dataModel]='dataModel'
          [workflowEngine]='workflowEngine'
      ></dc-ui-selector>
    </div>
  `
            }] }
];
ContainerRowComponent.propDecorators = {
    isRow: [{ type: HostBinding, args: ['class.row',] }]
};
class BSContainerRowProperties extends ContainerProperties {
}
/** @type {?} */
const example$1 = {
    title: 'Bootstrap container row example',
    uiModel: {
        type: 'bootstrap:bs-row',
        containerProperties: {
            width: '100%'
        },
        itemProperties: {
            width: '50%',
            padding: '10px'
        },
        children: [{
                type: 'material:text',
                containerProperties: {
                    fxFlex: '1 1 auto'
                },
                itemProperties: {
                    text: 'Text line 1',
                }
            }, {
                type: 'material:text',
                containerProperties: {
                    fxFlex: '1 1 auto'
                },
                itemProperties: {
                    text: 'Text line 2',
                }
            }]
    },
    dataModel: {}
};
/** @type {?} */
const containerRowDescriptor = {
    name: 'bs-row',
    packageName: 'bootstrap',
    category: 'Layout',
    description: 'Bootstrap row container',
    itemProperties: BSContainerRowProperties,
    component: ContainerRowComponent,
    example: example$1
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const COMPONENTS_LIST = [
    containerDescriptor,
    containerRowDescriptor
];
// Register components.
/**
 * @return {?}
 */
function registerComponents() {
    COMPONENTS_LIST.forEach((/**
     * @param {?} component
     * @return {?}
     */
    component => CoreService.registerComponent(component)));
}
/**
 * @return {?}
 */
function getCategories() {
    /** @type {?} */
    const categories = COMPONENTS_LIST.reduce((/**
     * @param {?} map
     * @param {?} desc
     * @return {?}
     */
    (map, desc) => {
        map[desc.category] = map[desc.category] || [];
        map[desc.category].push(desc);
        return map;
    }), {});
    return Object.entries(categories).map((/**
     * @param {?} __0
     * @return {?}
     */
    ([key, val]) => {
        return {
            name: key,
            components: val
        };
    }));
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BootstrapModule {
    constructor() {
        setTheme('bs4');
        registerComponents();
    }
}
BootstrapModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ContainerComponent, ContainerRowComponent],
                imports: [
                    CoreModule,
                    CommonModule
                ],
                exports: [ContainerComponent, ContainerRowComponent],
                entryComponents: [ContainerComponent, ContainerRowComponent]
            },] }
];
/** @nocollapse */
BootstrapModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { COMPONENTS_LIST, getCategories, BootstrapModule, BSContainerRowProperties as ɵe, ContainerRowComponent as ɵd, containerRowDescriptor as ɵf, BSContainerProperties as ɵb, ContainerComponent as ɵa, containerDescriptor as ɵc };

//# sourceMappingURL=ngx-dynamic-components-bootstrap.js.map